@@ -102,6 +102,9 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
 
     calcStats <- function(mydata, pollutant, data.thresh, percentile, ...) {
 
+        ## select only data needed
+        mydata <- mydata[c("date", pollutant, "site")]
+
         ## file any missing hours
         start.date <- as.POSIXct(dateTrunc(min(mydata$date), "year"))
         end.date <- as.POSIXct(dateCeil(max(mydata$date), "year") - 3600)
@@ -111,57 +114,57 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
         all.dates <- data.frame(date = seq(start.date, end.date, by = interval))
         mydata <- merge(mydata, all.dates, all = TRUE)
         mydata$year <- format(mydata$date, "%Y")
+
         
-       
         Mean <- group_by(mydata, year) %>%
           do(timeAverage(., avg.time = "year", statistic = "mean", data.thresh,
                          print.int = FALSE)) %>%
           rename_(mean = pollutant)
-        
+
         Min <- group_by(mydata, year) %>%
           do(timeAverage(., avg.time = "year", statistic = "min", data.thresh,
                          print.int = FALSE)) %>%
           rename_(minimum = pollutant)
-        
+
         Max <- group_by(mydata, year) %>%
           do(timeAverage(., avg.time = "year", statistic = "max", data.thresh,
                          print.int = FALSE)) %>%
           rename_(maximum = pollutant)
-        
+
         maxDaily <- group_by(mydata, year) %>%
           do(timeAverage(., avg.time = "day", statistic = "mean", data.thresh,
                          print.int = FALSE)) %>%
                            do(timeAverage(., avg.time = "year", statistic = "max",
                                           data.thresh, print.int = FALSE)) %>%
           rename_(daily.max = pollutant)
-        
+
         Median <- group_by(mydata, year) %>%
           do(timeAverage(., avg.time = "year", statistic = "median", data.thresh)) %>%
           rename_(median = pollutant)
-        
+
         dataCapture <- group_by(mydata, year) %>%
           do(timeAverage(., avg.time = "year", statistic = "data.cap", data.thresh)) %>%
           rename_(dat.cap = pollutant)
-        
+
         rollMax8 <- group_by(mydata, year) %>%
           do(rollingMean(., pollutant = pollutant, data.thresh = data.thresh,
                          width = 8, new.name = pollutant)) %>%
                            do(timeAverage(., avg.time = "year", statistic = "max", data.thresh)) %>%
                            rename_(max.roll.8 = pollutant)
-        
+
         rollMax24 <- group_by(mydata, year) %>%
           do(rollingMean(., pollutant = pollutant, data.thresh = data.thresh,
                          width = 24, new.name = pollutant)) %>%
                            do(timeAverage(., avg.time = "year", statistic = "max", data.thresh)) %>%
                            rename_(max.roll.24 = pollutant)
-        
+
         Percentile <- group_by(mydata, year) %>%
           do(calcPercentile(., avg.time = "year", pollutant = pollutant,
                             data.thresh = data.thresh, percentile = percentile))
 
-        
+
         if (length(grep("o3", pollutant, ignore.case = TRUE)) == 1) {
-            
+
             rollingO3 <- group_by(mydata, year) %>%
               do(rollingMean(., pollutant, data.thresh = data.thresh)) %>%
               do(timeAverage(., avg.time = "day", statistic = "max", data.thresh = data.thresh)) %>%
@@ -178,7 +181,7 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
 
             rollingO3b$site <- Mean$site ## make sure all have same columns
             rollingO3b$date <- Mean$date
-            
+
             AOT40 <- group_by(mydata, year) %>%
               do(AOT40(., pollutant))
 
@@ -195,13 +198,13 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
         }
 
         if (length(grep("no2", pollutant, ignore.case = TRUE)) == 1) {
-            
+
             hours <- group_by(mydata, year) %>%
               summarise_(hours = interp(~ length(which(var > 200)),
                              var = as.name(pollutant)))
             hours$site <- Mean$site ## make sure all have same columns
             hours$date <- Mean$date
-            
+
             no2.results <- list(dataCapture, Mean, Min, Max, Median,  maxDaily, rollMax8,
                                 rollMax24, Percentile, hours)
             
@@ -236,13 +239,13 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
 
             co.results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8, rollMax24,
                                Percentile)
-            co.results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
+            co.results <- Reduce(function(x, y) merge(x, y, by = c('site', 'year', 'date'),
                                                     all = TRUE), co.results)
             co.results$pollutant <- "CO"
             results <- co.results
             results
         }
-
+        
 
         ## see if pollutant string in any pre-defined ones
         ## if not calculate basic stats
@@ -250,8 +253,10 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
 
             results <- list(dataCapture, Mean, Min, Max, Median, maxDaily, rollMax8, rollMax24,
                             Percentile)
-            results <- Reduce(function(x, y, by = 'year') merge(x, y, by = 'year',
-                                                 all = TRUE), results)
+            
+            results <- Reduce(function(x, y) merge(x, y, by = c('site', 'year', 'date'),
+                                                   all = TRUE), results)
+            
             results$pollutant <- pollutant
             results <- results
 
@@ -275,16 +280,17 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
                                                             data.thresh = data.thresh,
                                                             percentile = percentile, ...))
 
-
+        
         results <- rbind_all(results)
         results$year <- as.numeric(results$year)
         results
     }
 
-    
+
     results <- group_by(mydata, site) %>%
       do(bySite(mydata, pollutant = pollutant, data.thresh = data.thresh,
                 percentile = percentile,...))
+    
 
     ## order sensible
     results <- cbind(subset(results, select = c(site, pollutant)), subset(results,
@@ -313,7 +319,7 @@ aqStats <- function(mydata, pollutant = "no2", data.thresh = 75, percentile = c(
 AOT40 <- function(mydata, pollutant, ...) {
     ## note the assumption is the O3 is in ug/m3
     daylight <- NULL
-    
+
     ## need daylight hours in growing season (April to September)
     mydata <- selectByDate(mydata, month = 4:9)
     mydata <- cutData(mydata, "daylight", ...)
