@@ -439,21 +439,21 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
             var1 <- "lon"
             var2 <- "lat"
         }
-
+        
         vars <- c(vars, "date")
 
         ## these are the map limits used for grid lines - in degrees
-        Args$trajLims <- c(range(mydata[, var1], na.rm = TRUE), range(mydata[, var2],
+        Args$trajLims <- c(range(mydata[[var1]], na.rm = TRUE), range(mydata[[var2]],
                                                      na.rm = TRUE) )
 
         ## apply map projection
-        tmp <- mapproject(x = mydata[, var1],
-                          y = mydata[, var2],
+        tmp <- mapproject(x = mydata[[var1]],
+                          y = mydata[[var2]],
                           projection = Args$projection,
                           parameters = Args$parameters,
                           orientation = Args$orientation)
-        mydata[, var1] <- tmp$x
-        mydata[, var2] <- tmp$y
+        mydata[[var1]] <- tmp$x
+        mydata[[var2]] <- tmp$y
 
     }
 
@@ -465,15 +465,15 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
 
     ## remove missing data except for time series where we want to show gaps
     ## this also removes missing factors
-    if (class(mydata[ , x])[1] != "Date" & !"POSIXt" %in% class(mydata[ , x])) {
+    if (class(mydata[[x]])[1] != "Date" & !"POSIXt" %in% class(mydata[ , x])) {
         mydata <- na.omit(mydata)
     }
 
     ## if x is a factor/character, then rotate axis labels for clearer labels
     x.rot <- 0
-    if ("factor" %in% class(mydata[, x]) | "character"  %in% class(mydata[, x])) {
+    if ("factor" %in% class(mydata[[x]]) | "character"  %in% class(mydata[, x])) {
         x.rot <- 90
-        mydata[, x] <- factor(mydata[, x])
+        mydata[, x] <- factor(mydata[[x]])
     }
 
     ## continuous colors ####################################################################
@@ -483,7 +483,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
             stop("You tried to use a date type for the 'z' variable. \nColour coding requires 'z' to be continuous numeric variable'")
 
         ## check to see if type is numeric/integer
-        if (class(mydata[, z]) %in% c("integer", "numeric") == FALSE)
+        if (class(mydata[[z]]) %in% c("integer", "numeric") == FALSE)
             stop(paste("Continuous colour coding requires ", z , " to be numeric", sep = ""))
 
         ## don't need a key with this
@@ -492,9 +492,9 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
         mydata <- cutData(mydata, type, ...)
 
         if (missing(cols)) cols <- "default" ## better default colours for this
-        thecol <- openColours(cols, 100)[cut(mydata[, z], 100, label = FALSE)]
+        thecol <- openColours(cols, 100)[cut(mydata[[z]], 100, label = FALSE)]
         mydata$col <- thecol
-
+        
         ## don't need to group by all levels - want one smooth etc
         group <- "NewGroupVar"
         mydata$NewGroupVar <- "NewGroupVar"
@@ -534,7 +534,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
             }
 
 
-            thecol <- openColours(cols, 100)[cut(mydata[, z],
+            thecol <- openColours(cols, 100)[cut(mydata[[z]],
                                                  breaks = seq(limits[1], limits[2],
                                                      length.out = 100), label = FALSE)]
             mydata$col <- thecol
@@ -703,7 +703,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
                                         
                                         ## colour by z
                                         lapply(tmp, function (dat)
-                                            llines(dat$lon, dat$lat, col.line = x$col,
+                                            llines(dat$lon, dat$lat, col.line = dat$col,
                                                    lwd = lwd, lty = lty))
                                         
                                       } else {
@@ -999,7 +999,9 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
 
 
     if (method %in% c("traj", "map")) {
-
+        if (missing(x.inc)) x.inc <- prettyGap(mydata[[x]])
+        if (missing(y.inc)) y.inc <- prettyGap(mydata[[y]])
+        
         ## bin data
         mydata$ygrid <- round_any(mydata[[y]], y.inc)
         mydata$xgrid <- round_any(mydata[[x]], x.inc)
@@ -1111,8 +1113,8 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
         nlev2 <- length(breaks)
 
         if (missing(cols)) cols <- "default"
-
-        thecol <- openColours(cols, length(breaks) - 1)[cut(mydata[, z], breaks, label = FALSE)]
+        
+        thecol <- openColours(cols, length(breaks) - 1)[cut(mydata[[z]], breaks, label = FALSE)]
         mydata$col <- thecol
         col <- thecol
 
@@ -1122,7 +1124,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
         col.scale <- breaks
 
         ## this is the default
-        if (trajStat %in% c("cwt", "pscf", "mean")) {
+        if (trajStat %in% c("cwt", "pscf", "mean", "frequency")) {
             legend <- list(col = col, at = breaks, labels = list(labels = labs),
                            space = key.position,
                            auto.text = auto.text, footer = Args$key.footer,
@@ -1131,7 +1133,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
             legend <- makeOpenKeyLegend(key, legend, "other")
         }
 
-        if (trajStat %in% c("frequency", "difference")) {
+        if (trajStat %in% c("frequency", "difference") && !smooth) {
 
             if (trajStat == "frequency") {
                 breaks <- c(0, 1, 5, 10, 25, 100)
@@ -1155,7 +1157,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
 
             col.scale <- breaks
 
-            thecol <- openColours(cols, length(breaks) - 1)[cut(mydata[, z], breaks, label = FALSE)]
+            thecol <- openColours(cols, length(breaks) - 1)[cut(mydata[[z]], breaks, label = FALSE)]
             mydata$col <- thecol
             col <- thecol
 
@@ -1342,15 +1344,17 @@ add.map <- function (Args, ...) {
     if (Args$map.res == "default") {
         res <- "world"
     } else {
-        res <- "worldHires"
-       
+        res <- "worldHires"       
     }
+
+    ## USA specific maps
+    if (Args$map.res == "state") 
+        res <- "state"
     
     if (Args$map.fill) {
 
         mp <- maps::map(database = res, plot = FALSE, fill = TRUE, projection = Args$projection,
-                  parameters = Args$parameters, orientation = Args$orientation,
-                  xlim = Args$trajLims[1:2], ylim = Args$trajLims[3:4])
+                  parameters = Args$parameters, orientation = Args$orientation)
         mp <- maps::map.wrap(mp)
 
         panel.polygon(mp$x, mp$y, col = Args$map.cols, border = "white",
